--[[Name: TranqShotMonitor
Description: Gives a message when tranquilizing Shot has dispelled succesfully, together with which buff was dispelled ]]

active = true
local yourname = UnitName("player")
local tasks = {}
----------------------------
-- Timing Functions ------
----------------------------
function TimingLib_Schedule(time, func, ...)
	local t = {...}
	t.func = func
	t.time = GetTime() + time
	table.insert(tasks, t)
end

local function onUpdate(self, elapsed)
	for i = #tasks, 1, -1 do
		local val = tasks[i]
		if val and val.time <= GetTime() then
			table.remove(tasks, i)
			val.func(unpack(val))
		end
	end
end

function TimingLib_Unschedule(func, ...)
	for i = #tasks, 1 , -1 do
		local val = tasks[i]
		if val.func == func then
			local matches = true
			for i = 1, select("#", ...) do
				if select(i, ...) ~=val[i] then
					matches = false
					break
				end
			end
			if matches then
				table.remove(tasks, i)
			end
		end
	end
end

function SimpleTimingLib_Unschedule(func, ...)
	return unschedule(func, nil, ...)
end

function SimpleTimingLib_Schedule(time, func, ...)
	return schedule(time, func, nil, ...)
end

----------------------------------------
---- Handling the tranq shots --------
------------------------------------------

local frame = CreateFrame("Frame","TRANQWARNINGFRAME",UIParent)
frame:ClearAllPoints()
frame:SetPoint("TOP",UIParent)
frame:SetWidth(200)
frame:SetHeight(200)
frame:Show()

-----------------
-- warning ------
-----------------

local fontstring=frame:CreateFontString()
fontstring:ClearAllPoints()
fontstring:SetPoint("BOTTOM",frame)
fontstring:SetFont("Fonts\\FRIZQT__.TTF", 30)
fontstring:SetWidth(500)
fontstring:SetJustifyH("CENTER")
fontstring:SetHeight(40)


-------------------
-- event handler --
-------------------

function onEvent(self, event, ...)
	local tranqshotmsg = "Tranquilizing Shot dispelled "
	local timestamp, type, sourceGUID, sourceName, sourceFlags, destGUID, destName, destFlags = select(1, ...)

	if active == true and event == "COMBAT_LOG_EVENT_UNFILTERED" and sourceName == yourname then
		if (type=="SPELL_DISPEL") then
			local spellId, spellName, spellSchool = select(9, ...)
			local extraSpellID, extraSpellName, extraSchool, auraType = select(12, ...)
	
			if (spellName=="Tranquilizing Shot") then
				local msg = tranqshotmsg..extraSpellName.." !"
				fontstring:SetText(msg)
				fontstring:Show()
				TimingLib_Schedule(3, function() fontstring:Hide() end)

			end
		end
	end
end



frame:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
local e = 0
frame:SetScript("OnUpdate", function(self, elapsed)
	e  = e + elapsed
	if e >= 0.5 then
		e = 0
		return onUpdate(self, elapsed)
	end
end)
frame:SetScript("OnEvent", onEvent)

SLASH_TranqShotMonitor1 = "/tranqshotmonitor"
SLASH_TranqShotMonitor2 = "/tsm"

---------------------
--- slash commands-----
--- /tsm enable-------
---- /tsm disable ----
----------------------

SlashCmdList["TranqShotMonitor"] = function(msg)
	local cmd = string.split(" ", msg) --split the string
	cmd = cmd:lower() 
	if cmd == "enable" then -- /tsm enable
		active = true
		print("[TranqShotMonitor] Enabled")
	elseif cmd == "disable" then -- /tsm disable
		active = false
		print("[TranqShotMonitor] Disabled")
	end
end
